==> rust-winit_0.28.6.orig.tar.gz: winit-0.28.6/src/platform_impl/ios/uikit/view_controller.rs <==
use objc2::encode::{Encode, Encoding};
use objc2::foundation::{NSObject, NSUInteger};
use objc2::rc::{Id, Shared};
use objc2::{extern_class, extern_methods, msg_send_id, ClassType};

use super::{UIResponder, UIView};

extern_class!(
    #[derive(Debug, PartialEq, Eq, Hash)]
    pub(crate) struct UIViewController;

    unsafe impl ClassType for UIViewController {
        #[inherits(NSObject)]
        type Super = UIResponder;
    }
);

extern_methods!(
    unsafe impl UIViewController {
        #[sel(attemptRotationToDeviceOrientation)]
        pub fn attemptRotationToDeviceOrientation();

        #[sel(setNeedsStatusBarAppearanceUpdate)]
        pub fn setNeedsStatusBarAppearanceUpdate(&self);

        #[sel(setNeedsUpdateOfHomeIndicatorAutoHidden)]
        pub fn setNeedsUpdateOfHomeIndicatorAutoHidden(&self);

        #[sel(setNeedsUpdateOfScreenEdgesDeferringSystemGestures)]
        pub fn setNeedsUpdateOfScreenEdgesDeferringSystemGestures(&self);

        pub fn view(&self) -> Option<Id<UIView, Shared>> {
            unsafe { msg_send_id![self, view] }
        }

        #[sel(setView:)]
        pub fn setView(&self, view: Option<&UIView>);
    }
);

bitflags! {
    pub struct UIInterfaceOrientationMask: NSUInteger {
        const Portrait = 1 << 1;
        const PortraitUpsideDown = 1 << 2;
        const LandscapeRight = 1 << 3;
        const LandscapeLeft = 1 << 4;
        const Landscape = Self::LandscapeLeft.bits() | Self::LandscapeRight.bits();
        const AllButUpsideDown = Self::Landscape.bits() | Self::Portrait.bits();
        const All = Self::AllButUpsideDown.bits() | Self::PortraitUpsideDown.bits();
    }
}

unsafe impl Encode for UIInterfaceOrientationMask {
    const ENCODING: Encoding = NSUInteger::ENCODING;
}

==> rust-winit_0.29.15.orig.tar.gz: winit-0.29.15/src/platform_impl/ios/uikit/view_controller.rs <==
use icrate::Foundation::{NSObject, NSUInteger};
use objc2::encode::{Encode, Encoding};
use objc2::rc::Id;
use objc2::{extern_class, extern_methods, msg_send_id, mutability, ClassType};

use super::{UIResponder, UIView};

extern_class!(
    #[derive(Debug, PartialEq, Eq, Hash)]
    pub(crate) struct UIViewController;

    unsafe impl ClassType for UIViewController {
        #[inherits(NSObject)]
        type Super = UIResponder;
        type Mutability = mutability::InteriorMutable;
    }
);

extern_methods!(
    unsafe impl UIViewController {
        #[method(attemptRotationToDeviceOrientation)]
        pub fn attemptRotationToDeviceOrientation();

        #[method(setNeedsStatusBarAppearanceUpdate)]
        pub fn setNeedsStatusBarAppearanceUpdate(&self);

        #[method(setNeedsUpdateOfHomeIndicatorAutoHidden)]
        pub fn setNeedsUpdateOfHomeIndicatorAutoHidden(&self);

        #[method(setNeedsUpdateOfScreenEdgesDeferringSystemGestures)]
        pub fn setNeedsUpdateOfScreenEdgesDeferringSystemGestures(&self);

        pub fn view(&self) -> Option<Id<UIView>> {
            unsafe { msg_send_id![self, view] }
        }

        #[method(setView:)]
        pub fn setView(&self, view: Option<&UIView>);
    }
);

bitflags! {
    #[derive(Clone, Copy)]
    pub struct UIInterfaceOrientationMask: NSUInteger {
        const Portrait = 1 << 1;
        const PortraitUpsideDown = 1 << 2;
        const LandscapeRight = 1 << 3;
        const LandscapeLeft = 1 << 4;
        const Landscape = Self::LandscapeLeft.bits() | Self::LandscapeRight.bits();
        const AllButUpsideDown = Self::Landscape.bits() | Self::Portrait.bits();
        const All = Self::AllButUpsideDown.bits() | Self::PortraitUpsideDown.bits();
    }
}

unsafe impl Encode for UIInterfaceOrientationMask {
    const ENCODING: Encoding = NSUInteger::ENCODING;
}
